@@ -6,14 +6,15 @@ Type annotations for transfer service client.
 Usage::
 
     ```python
-    import boto3
-    from mypy_boto3_transfer import TransferClient
+    from boto3.session import Session
+    from mypy_boto3_transfer.client import TransferClient
 
-    client: TransferClient = boto3.client("transfer")
+    session = Session()
+    client: TransferClient = session.client("transfer")
     ```
 """
 import sys
-from typing import Any, Dict, Mapping, Sequence, Type
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -25,7 +26,15 @@ from .literals import (
     IdentityProviderTypeType,
     ProtocolType,
 )
-from .paginator import ListServersPaginator
+from .paginator import (
+    ListAccessesPaginator,
+    ListExecutionsPaginator,
+    ListSecurityPoliciesPaginator,
+    ListServersPaginator,
+    ListTagsForResourcePaginator,
+    ListUsersPaginator,
+    ListWorkflowsPaginator,
+)
 from .type_defs import (
     CreateAccessResponseTypeDef,
     CreateServerResponseTypeDef,
@@ -91,7 +100,7 @@ class Exceptions:
 
 class TransferClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html)
     """
 
@@ -101,13 +110,16 @@ class TransferClient(BaseClient):
     def exceptions(self) -> Exceptions:
         """
         TransferClient exceptions.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.exceptions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#exceptions)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#can_paginate)
         """
 
@@ -128,7 +140,7 @@ class TransferClient(BaseClient):
         access to upload and download files over the enabled protocols using Amazon Web
         Services Transfer Family.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.create_access)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.create_access)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#create_access)
         """
 
@@ -143,7 +155,10 @@ class TransferClient(BaseClient):
         IdentityProviderDetails: "IdentityProviderDetailsTypeDef" = ...,
         IdentityProviderType: IdentityProviderTypeType = ...,
         LoggingRole: str = ...,
+        PostAuthenticationLoginBanner: str = ...,
+        PreAuthenticationLoginBanner: str = ...,
         Protocols: Sequence[ProtocolType] = ...,
+        ProtocolDetails: "ProtocolDetailsTypeDef" = ...,
         SecurityPolicyName: str = ...,
         Tags: Sequence["TagTypeDef"] = ...,
         WorkflowDetails: "WorkflowDetailsTypeDef" = ...
@@ -152,7 +167,7 @@ class TransferClient(BaseClient):
         Instantiates an auto-scaling virtual server based on the selected file transfer
         protocol in Amazon Web Services.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.create_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.create_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#create_server)
         """
 
@@ -174,7 +189,7 @@ class TransferClient(BaseClient):
         Creates a user and associates them with an existing file transfer protocol-
         enabled server.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.create_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.create_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#create_user)
         """
 
@@ -190,7 +205,7 @@ class TransferClient(BaseClient):
         Allows you to create a workflow with specified steps and step details the
         workflow invokes after file transfer completes.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.create_workflow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.create_workflow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#create_workflow)
         """
 
@@ -199,7 +214,7 @@ class TransferClient(BaseClient):
         Allows you to delete the access specified in the `ServerID` and `ExternalID`
         parameters.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.delete_access)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.delete_access)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#delete_access)
         """
 
@@ -207,7 +222,7 @@ class TransferClient(BaseClient):
         """
         Deletes the file transfer protocol-enabled server that you specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.delete_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.delete_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#delete_server)
         """
 
@@ -215,7 +230,7 @@ class TransferClient(BaseClient):
         """
         Deletes a user's Secure Shell (SSH) public key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.delete_ssh_public_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.delete_ssh_public_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#delete_ssh_public_key)
         """
 
@@ -224,7 +239,7 @@ class TransferClient(BaseClient):
         Deletes the user belonging to a file transfer protocol-enabled server you
         specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.delete_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.delete_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#delete_user)
         """
 
@@ -232,7 +247,7 @@ class TransferClient(BaseClient):
         """
         Deletes the specified workflow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.delete_workflow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.delete_workflow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#delete_workflow)
         """
 
@@ -241,7 +256,7 @@ class TransferClient(BaseClient):
         Describes the access that is assigned to the specific file transfer protocol-
         enabled server, as identified by its `ServerId` property and its `ExternalID` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.describe_access)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.describe_access)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_access)
         """
 
@@ -252,7 +267,7 @@ class TransferClient(BaseClient):
         You can use `DescribeExecution` to check the details of the execution of the
         specified workflow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.describe_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.describe_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_execution)
         """
 
@@ -263,7 +278,7 @@ class TransferClient(BaseClient):
         Describes the security policy that is attached to your file transfer protocol-
         enabled server.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.describe_security_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.describe_security_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_security_policy)
         """
 
@@ -272,7 +287,7 @@ class TransferClient(BaseClient):
         Describes a file transfer protocol-enabled server that you specify by passing
         the `ServerId` parameter.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.describe_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.describe_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_server)
         """
 
@@ -281,7 +296,7 @@ class TransferClient(BaseClient):
         Describes the user assigned to the specific file transfer protocol-enabled
         server, as identified by its `ServerId` property.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.describe_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.describe_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_user)
         """
 
@@ -289,7 +304,7 @@ class TransferClient(BaseClient):
         """
         Describes the specified workflow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.describe_workflow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.describe_workflow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_workflow)
         """
 
@@ -303,7 +318,7 @@ class TransferClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#generate_presigned_url)
         """
 
@@ -315,7 +330,7 @@ class TransferClient(BaseClient):
         `UserName` value assigned to the specific file transfer protocol-enabled server,
         identified by `ServerId` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.import_ssh_public_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.import_ssh_public_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#import_ssh_public_key)
         """
 
@@ -325,7 +340,7 @@ class TransferClient(BaseClient):
         """
         Lists the details for all the accesses you have on your server.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.list_accesses)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.list_accesses)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_accesses)
         """
 
@@ -335,7 +350,7 @@ class TransferClient(BaseClient):
         """
         Lists all executions for the specified workflow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.list_executions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.list_executions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_executions)
         """
 
@@ -346,7 +361,7 @@ class TransferClient(BaseClient):
         Lists the security policies that are attached to your file transfer protocol-
         enabled servers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.list_security_policies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.list_security_policies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_security_policies)
         """
 
@@ -357,7 +372,7 @@ class TransferClient(BaseClient):
         Lists the file transfer protocol-enabled servers that are associated with your
         Amazon Web Services account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.list_servers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.list_servers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_servers)
         """
 
@@ -368,7 +383,7 @@ class TransferClient(BaseClient):
         Lists all of the tags associated with the Amazon Resource Name (ARN) that you
         specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_tags_for_resource)
         """
 
@@ -379,7 +394,7 @@ class TransferClient(BaseClient):
         Lists the users for a file transfer protocol-enabled server that you specify by
         passing the `ServerId` parameter.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.list_users)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.list_users)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_users)
         """
 
@@ -389,7 +404,7 @@ class TransferClient(BaseClient):
         """
         Lists all of your workflows.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.list_workflows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.list_workflows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_workflows)
         """
 
@@ -399,7 +414,7 @@ class TransferClient(BaseClient):
         """
         Sends a callback for asynchronous custom steps.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.send_workflow_step_state)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.send_workflow_step_state)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#send_workflow_step_state)
         """
 
@@ -408,7 +423,7 @@ class TransferClient(BaseClient):
         Changes the state of a file transfer protocol-enabled server from `OFFLINE` to
         `ONLINE`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.start_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.start_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#start_server)
         """
 
@@ -417,7 +432,7 @@ class TransferClient(BaseClient):
         Changes the state of a file transfer protocol-enabled server from `ONLINE` to
         `OFFLINE`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.stop_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.stop_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#stop_server)
         """
 
@@ -426,7 +441,7 @@ class TransferClient(BaseClient):
         Attaches a key-value pair to a resource, as identified by its Amazon Resource
         Name (ARN).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#tag_resource)
         """
 
@@ -444,7 +459,7 @@ class TransferClient(BaseClient):
         `AWS_DIRECTORY_SERVICE` or `API_Gateway` , tests whether your identity provider
         is set up successfully.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.test_identity_provider)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.test_identity_provider)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#test_identity_provider)
         """
 
@@ -453,7 +468,7 @@ class TransferClient(BaseClient):
         Detaches a key-value pair from a resource, as identified by its Amazon Resource
         Name (ARN).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#untag_resource)
         """
 
@@ -473,7 +488,7 @@ class TransferClient(BaseClient):
         Allows you to update parameters for the access specified in the `ServerID` and
         `ExternalID` parameters.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.update_access)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.update_access)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#update_access)
         """
 
@@ -488,6 +503,8 @@ class TransferClient(BaseClient):
         HostKey: str = ...,
         IdentityProviderDetails: "IdentityProviderDetailsTypeDef" = ...,
         LoggingRole: str = ...,
+        PostAuthenticationLoginBanner: str = ...,
+        PreAuthenticationLoginBanner: str = ...,
         Protocols: Sequence[ProtocolType] = ...,
         SecurityPolicyName: str = ...,
         WorkflowDetails: "WorkflowDetailsTypeDef" = ...
@@ -496,7 +513,7 @@ class TransferClient(BaseClient):
         Updates the file transfer protocol-enabled server's properties after that server
         has been created.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.update_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.update_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#update_server)
         """
 
@@ -515,12 +532,59 @@ class TransferClient(BaseClient):
         """
         Assigns new properties to a user.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Client.update_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.update_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#update_user)
         """
 
+    @overload
+    def get_paginator(self, operation_name: Literal["list_accesses"]) -> ListAccessesPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#get_paginator)
+        """
+
+    @overload
+    def get_paginator(self, operation_name: Literal["list_executions"]) -> ListExecutionsPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#get_paginator)
+        """
+
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["list_security_policies"]
+    ) -> ListSecurityPoliciesPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#get_paginator)
+        """
+
+    @overload
     def get_paginator(self, operation_name: Literal["list_servers"]) -> ListServersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/transfer.html#Transfer.Paginator.ListServers)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/paginators.html#listserverspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#get_paginator)
+        """
+
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["list_tags_for_resource"]
+    ) -> ListTagsForResourcePaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#get_paginator)
+        """
+
+    @overload
+    def get_paginator(self, operation_name: Literal["list_users"]) -> ListUsersPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#get_paginator)
+        """
+
+    @overload
+    def get_paginator(self, operation_name: Literal["list_workflows"]) -> ListWorkflowsPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#get_paginator)
         """
