@@ -27,10 +27,17 @@ __all__ = (
     "ExecutionStatusType",
     "HomeDirectoryTypeType",
     "IdentityProviderTypeType",
+    "ListAccessesPaginatorName",
+    "ListExecutionsPaginatorName",
+    "ListSecurityPoliciesPaginatorName",
     "ListServersPaginatorName",
+    "ListTagsForResourcePaginatorName",
+    "ListUsersPaginatorName",
+    "ListWorkflowsPaginatorName",
     "OverwriteExistingType",
     "ProtocolType",
     "StateType",
+    "TlsSessionResumptionModeType",
     "WorkflowStepTypeType",
     "ServiceName",
     "PaginatorName",
@@ -43,11 +50,20 @@ EndpointTypeType = Literal["PUBLIC", "VPC", "VPC_ENDPOINT"]
 ExecutionErrorTypeType = Literal["PERMISSION_DENIED"]
 ExecutionStatusType = Literal["COMPLETED", "EXCEPTION", "HANDLING_EXCEPTION", "IN_PROGRESS"]
 HomeDirectoryTypeType = Literal["LOGICAL", "PATH"]
-IdentityProviderTypeType = Literal["API_GATEWAY", "AWS_DIRECTORY_SERVICE", "SERVICE_MANAGED"]
+IdentityProviderTypeType = Literal[
+    "API_GATEWAY", "AWS_DIRECTORY_SERVICE", "AWS_LAMBDA", "SERVICE_MANAGED"
+]
+ListAccessesPaginatorName = Literal["list_accesses"]
+ListExecutionsPaginatorName = Literal["list_executions"]
+ListSecurityPoliciesPaginatorName = Literal["list_security_policies"]
 ListServersPaginatorName = Literal["list_servers"]
+ListTagsForResourcePaginatorName = Literal["list_tags_for_resource"]
+ListUsersPaginatorName = Literal["list_users"]
+ListWorkflowsPaginatorName = Literal["list_workflows"]
 OverwriteExistingType = Literal["FALSE", "TRUE"]
 ProtocolType = Literal["FTP", "FTPS", "SFTP"]
 StateType = Literal["OFFLINE", "ONLINE", "STARTING", "START_FAILED", "STOPPING", "STOP_FAILED"]
+TlsSessionResumptionModeType = Literal["DISABLED", "ENABLED", "ENFORCED"]
 WorkflowStepTypeType = Literal["COPY", "CUSTOM", "DELETE", "TAG"]
 ServiceName = Literal[
     "accessanalyzer",
@@ -58,10 +74,12 @@ ServiceName = Literal[
     "amp",
     "amplify",
     "amplifybackend",
+    "amplifyuibuilder",
     "apigateway",
     "apigatewaymanagementapi",
     "apigatewayv2",
     "appconfig",
+    "appconfigdata",
     "appflow",
     "appintegrations",
     "application-autoscaling",
@@ -76,12 +94,14 @@ ServiceName = Literal[
     "autoscaling",
     "autoscaling-plans",
     "backup",
+    "backup-gateway",
     "batch",
     "braket",
     "budgets",
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
     "cloudcontrol",
@@ -129,6 +149,7 @@ ServiceName = Literal[
     "dlm",
     "dms",
     "docdb",
+    "drs",
     "ds",
     "dynamodb",
     "dynamodbstreams",
@@ -150,6 +171,7 @@ ServiceName = Literal[
     "emr-containers",
     "es",
     "events",
+    "evidently",
     "finspace",
     "finspace-data",
     "firehose",
@@ -176,6 +198,7 @@ ServiceName = Literal[
     "imagebuilder",
     "importexport",
     "inspector",
+    "inspector2",
     "iot",
     "iot-data",
     "iot-jobs-data",
@@ -189,6 +212,7 @@ ServiceName = Literal[
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
+    "iottwinmaker",
     "iotwireless",
     "ivs",
     "kafka",
@@ -234,7 +258,9 @@ ServiceName = Literal[
     "meteringmarketplace",
     "mgh",
     "mgn",
+    "migration-hub-refactor-spaces",
     "migrationhub-config",
+    "migrationhubstrategy",
     "mobile",
     "mq",
     "mturk",
@@ -263,11 +289,13 @@ ServiceName = Literal[
     "qldb-session",
     "quicksight",
     "ram",
+    "rbin",
     "rds",
     "rds-data",
     "redshift",
     "redshift-data",
     "rekognition",
+    "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -277,6 +305,7 @@ ServiceName = Literal[
     "route53-recovery-readiness",
     "route53domains",
     "route53resolver",
+    "rum",
     "s3",
     "s3control",
     "s3outposts",
@@ -334,6 +363,15 @@ ServiceName = Literal[
     "workmail",
     "workmailmessageflow",
     "workspaces",
+    "workspaces-web",
     "xray",
 ]
-PaginatorName = Literal["list_servers"]
+PaginatorName = Literal[
+    "list_accesses",
+    "list_executions",
+    "list_security_policies",
+    "list_servers",
+    "list_tags_for_resource",
+    "list_users",
+    "list_workflows",
+]
