@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Sequence
+from typing import Dict, List, Sequence
 
 from .literals import (
     CustomStepStatusType,
@@ -25,6 +25,7 @@ from .literals import (
     OverwriteExistingType,
     ProtocolType,
     StateType,
+    TlsSessionResumptionModeType,
     WorkflowStepTypeType,
 )
 
@@ -140,6 +141,7 @@ CopyStepDetailsTypeDef = TypedDict(
         "Name": str,
         "DestinationFileLocation": "InputFileLocationTypeDef",
         "OverwriteExisting": OverwriteExistingType,
+        "SourceFileLocation": str,
     },
     total=False,
 )
@@ -191,7 +193,10 @@ CreateServerRequestRequestTypeDef = TypedDict(
         "IdentityProviderDetails": "IdentityProviderDetailsTypeDef",
         "IdentityProviderType": IdentityProviderTypeType,
         "LoggingRole": str,
+        "PostAuthenticationLoginBanner": str,
+        "PreAuthenticationLoginBanner": str,
         "Protocols": Sequence[ProtocolType],
+        "ProtocolDetails": "ProtocolDetailsTypeDef",
         "SecurityPolicyName": str,
         "Tags": Sequence["TagTypeDef"],
         "WorkflowDetails": "WorkflowDetailsTypeDef",
@@ -282,6 +287,7 @@ CustomStepDetailsTypeDef = TypedDict(
         "Name": str,
         "Target": str,
         "TimeoutSeconds": int,
+        "SourceFileLocation": str,
     },
     total=False,
 )
@@ -314,6 +320,7 @@ DeleteStepDetailsTypeDef = TypedDict(
     "DeleteStepDetailsTypeDef",
     {
         "Name": str,
+        "SourceFileLocation": str,
     },
     total=False,
 )
@@ -501,6 +508,8 @@ _OptionalDescribedServerTypeDef = TypedDict(
         "IdentityProviderDetails": "IdentityProviderDetailsTypeDef",
         "IdentityProviderType": IdentityProviderTypeType,
         "LoggingRole": str,
+        "PostAuthenticationLoginBanner": str,
+        "PreAuthenticationLoginBanner": str,
         "Protocols": List[ProtocolType],
         "SecurityPolicyName": str,
         "ServerId": str,
@@ -640,6 +649,7 @@ IdentityProviderDetailsTypeDef = TypedDict(
         "Url": str,
         "InvocationRole": str,
         "DirectoryId": str,
+        "Function": str,
     },
     total=False,
 )
@@ -978,6 +988,7 @@ ProtocolDetailsTypeDef = TypedDict(
     "ProtocolDetailsTypeDef",
     {
         "PassiveIp": str,
+        "TlsSessionResumptionMode": TlsSessionResumptionModeType,
     },
     total=False,
 )
@@ -988,7 +999,7 @@ ResponseMetadataTypeDef = TypedDict(
         "RequestId": str,
         "HostId": str,
         "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
+        "HTTPHeaders": Dict[str, str],
         "RetryAttempts": int,
     },
 )
@@ -1074,6 +1085,7 @@ TagStepDetailsTypeDef = TypedDict(
     {
         "Name": str,
         "Tags": Sequence["S3TagTypeDef"],
+        "SourceFileLocation": str,
     },
     total=False,
 )
@@ -1182,6 +1194,8 @@ _OptionalUpdateServerRequestRequestTypeDef = TypedDict(
         "HostKey": str,
         "IdentityProviderDetails": "IdentityProviderDetailsTypeDef",
         "LoggingRole": str,
+        "PostAuthenticationLoginBanner": str,
+        "PreAuthenticationLoginBanner": str,
         "Protocols": Sequence[ProtocolType],
         "SecurityPolicyName": str,
         "WorkflowDetails": "WorkflowDetailsTypeDef",
